@@ -6,7 +6,18 @@ use lib "lib";
 
 use Image::Hash;
 use File::Slurp;
+use Getopt::Std;
 
+my %opts;
+getopts('l:', \%opts);
+
+my @modules;
+if ($opts{'l'}) {
+	@modules = split(/,/, $opts{'l'});
+}
+else {
+	@modules =  qw( GD ImageMagick Imager );
+}
 
 if ($#ARGV < 0) {
 	die("Pleas spesyfi at least one file to read!");
@@ -21,26 +32,26 @@ while (my $file = shift @ARGV) {
 
 
 	print "ahash:\n";
-	for my $module ( qw( GD ImageMagick Imager ) ) {
+	for my $module ( @modules ) {
 		my $ihash = Image::Hash->new($image, $module);
 		printf("%-15s: %-16s %s\n", $module, scalar $ihash->ahash(), join('', $ihash->ahash()));
 	}
 
 	print "\ndhash:\n";
-	for my $module ( qw( GD ImageMagick Imager ) ) {
+	for my $module ( @modules ) {
 		my $ihash = Image::Hash->new($image, $module);
 		printf("%-15s: %-16s %s\n", $module, scalar $ihash->dhash(), join('', $ihash->dhash()));
 	}
 
 	print "\nphash:\n";
-	for my $module ( qw( GD ImageMagick Imager ) ) {
+	for my $module ( @modules ) {
 		my $ihash = Image::Hash->new($image, $module);
 		printf("%-15s: %-16s %s\n", $module, scalar $ihash->phash(), join('', $ihash->phash()));
 	}
 
 
 	print "\ndump with aHash highlighted:\n";
-	for my $module ( qw( GD ImageMagick Imager ) ) {
+	for my $module ( @modules ) {
 		my $ihash = Image::Hash->new($image, $module);
 
 		print "$module:\n";
